@@ -4,7 +4,7 @@
 #include <string.h>
 #include <math.h>
 #include "psrcat.h"
- 
+
 void defineCustom(pulsar *psr,int ip,int type,int exactMatch);
 void defineDegrees(pulsar *psr,int ip,int type);
 void defineBinary(pulsar *psr,int ip,int type);
@@ -40,7 +40,7 @@ int getParam(char *str,pulsar *psr)
 	    deriveParameter(str,psr,i);
 	  return i;
 	}
-    }  
+    }
   return -1;
 }
 
@@ -149,7 +149,7 @@ void deriveParameter(char *str,pulsar *psr,int ip)
   /* Ecliptic coordinates */
   /* ******************** */
   if (strcmp(str,"ELONG")==0 || strcmp(str,"ELAT")==0) defineEcliptic(psr,ip,1);
-  if (strcmp(str,"RAJ")==0 || strcmp(str,"DECJ")==0 
+  if (strcmp(str,"RAJ")==0 || strcmp(str,"DECJ")==0
       || strcmp(str,"RAJD")==0 || strcmp(str,"DECJD")==0) defineEquatorial(psr,ip,1);
   if (strcmp(str,"PMRA")==0 || strcmp(str,"PMDEC")==0)     defineEquatorial(psr,ip,2);
 
@@ -182,9 +182,9 @@ void derive_oSurvey(pulsar *psr,int ip,int type)
     {
       strcpy(old_survey,psr->param[ip1].val);
       osurvey_val = encode_survey(old_survey,surveyNum,surveynames);
-      psr->param[ip].set1 = 1; psr->param[ip].shortVal = (double)osurvey_val; 
-      sprintf(psr->param[ip].val,"%12.12lo",osurvey_val);  
-      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);              
+      psr->param[ip].set1 = 1; psr->param[ip].shortVal = (double)osurvey_val;
+      sprintf(psr->param[ip].val,"%12.12lo",osurvey_val);
+      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
 }
 
@@ -206,9 +206,9 @@ void definePosEpoch(pulsar *psr,int ip,int type)
       if (psr->param[ip1].set1==1)
 	{
 	  val1 = psr->param[ip1].shortVal;
-	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = val1; sprintf(psr->param[ip].val,"%8.2f",val1);  
+	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = val1; sprintf(psr->param[ip].val,"%8.2f",val1);
 	  psr->param[ip].derived = 1;
-	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);              
+	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
 	}
     }
   else if (type==2) /* Discovery date */
@@ -235,10 +235,10 @@ void definePosEpoch(pulsar *psr,int ip,int type)
 	    date = 1900+date;
 	  else
 	    date = 2000+date;
-	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = date; sprintf(psr->param[ip].val,"%-5d",date);  
+	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = date; sprintf(psr->param[ip].val,"%-5d",date);
 	  psr->param[ip].derived = 1;
-	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);             
-	}      
+	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
+	}
     }
 }
 
@@ -255,9 +255,9 @@ void defineDMEpoch(pulsar *psr,int ip,int type)
   if (psr->param[ip1].set1==1)
     {
       val1 = psr->param[ip1].shortVal;
-      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val1; sprintf(psr->param[ip].val,"%8.2f",val1);  
+      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val1; sprintf(psr->param[ip].val,"%8.2f",val1);
       psr->param[ip].derived = 1;
-      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);              
+      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
 }
 
@@ -269,15 +269,15 @@ void defineFlux(pulsar *psr,int ip,int type)
 
   ip1 = getParam("S1400",NULL);
   ip2 = getParam("S400",NULL);
-  
+
   if (type==1 && psr->param[ip1].set1==1 && psr->param[ip2].set1==1) /* SI414 */
     {
       val1 = psr->param[ip2].shortVal;
       val2 = psr->param[ip1].shortVal;
       val  = -log10(val1/val2)/(log10(400.0/1400.0));
-      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.2f",val);  
+      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.2f",val);
       psr->param[ip].derived = 1;
-      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);            
+      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
   else if (type==2 && psr->param[ip2].set1==1) /* R_LUM */
     {
@@ -287,9 +287,9 @@ void defineFlux(pulsar *psr,int ip,int type)
 	  val1 = psr->param[ip2].shortVal;
 	  val2 = psr->param[ip3].shortVal;
 	  val3 = val1*val2*val2;
-	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = val3; sprintf(psr->param[ip].val,"%-8.2f",val3); 
+	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = val3; sprintf(psr->param[ip].val,"%-8.2f",val3);
 	  psr->param[ip].derived = 1;
-	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);            
+	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
 	}
     }
   else if (type==3 && psr->param[ip1].set1==1) /* R_LUM14 */
@@ -300,12 +300,12 @@ void defineFlux(pulsar *psr,int ip,int type)
 	  val1 = psr->param[ip1].shortVal;
 	  val2 = psr->param[ip3].shortVal;
 	  val3 = val1*val2*val2;
-	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = val3; sprintf(psr->param[ip].val,"%-8.2f",val3);  
+	  psr->param[ip].set1 = 1; psr->param[ip].shortVal = val3; sprintf(psr->param[ip].val,"%-8.2f",val3);
 	  psr->param[ip].derived = 1;
-	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);            
+	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
 	}
     }
-    
+
 }
 /* *********************** */
 /* Based on proper motions */
@@ -324,17 +324,17 @@ void definePM(pulsar *psr,int ip,int type)
       if (psr->param[ip1].set1 != 1 || psr->param[ip2].set1 != 1)
 	{
 	  ip1 = getParam("PMELONG",psr);
-	  ip2 = getParam("PMELAT",psr);	  
+	  ip2 = getParam("PMELAT",psr);
 	}
-      
-           
+
+
       if (psr->param[ip1].set1 == 1 && psr->param[ip2].set1 == 1)
 	{
 	  val1 = psr->param[ip1].shortVal;
 	  val2 = psr->param[ip2].shortVal;
-	
+
 	  sscanf(psr->param[ip1].err,"%d",&ierr1);
-	  sscanf(psr->param[ip2].err,"%d",&ierr2);	      
+	  sscanf(psr->param[ip2].err,"%d",&ierr2);
 	  err1 = psr->param[ip1].error_expand*ierr1;
 	  err2 = psr->param[ip2].error_expand*ierr2;
 	  err  = sqrt((pow(val1*err1,2)+pow(val2*err2,2))/(val1*val1 + val2*val2));
@@ -345,7 +345,7 @@ void definePM(pulsar *psr,int ip,int type)
 	  psr->param[ip].derived = 1;
 	  psr->param[ip].set1 = 1;
 	  psr->param[ip].set2 = 1;
-	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val); 
+	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
 	  pcat_errZero[ip]=1;
 	}
       else
@@ -404,7 +404,7 @@ void definePM(pulsar *psr,int ip,int type)
 	  psr->param[ip6].shortVal = val5;
 	  psr->param[ip6].set1 = 1;
 	  psr->param[ip6].derived = 1;
-	  if (pcat_maxSize[ip6] < strlen(psr->param[ip6].val)) pcat_maxSize[ip6]=strlen(psr->param[ip6].val);	  
+	  if (pcat_maxSize[ip6] < strlen(psr->param[ip6].val)) pcat_maxSize[ip6]=strlen(psr->param[ip6].val);
 
 	  /* Set BSURF_I */
 	  val5 = 3.2e19*sqrt(val3*val);
@@ -412,15 +412,15 @@ void definePM(pulsar *psr,int ip,int type)
 	  psr->param[ip7].shortVal = val5;
 	  psr->param[ip7].set1 = 1;
 	  psr->param[ip7].derived = 1;
-	  if (pcat_maxSize[ip7] < strlen(psr->param[ip7].val)) pcat_maxSize[ip7]=strlen(psr->param[ip7].val);	  
+	  if (pcat_maxSize[ip7] < strlen(psr->param[ip7].val)) pcat_maxSize[ip7]=strlen(psr->param[ip7].val);
 
 	  /* Set EDOT_I */
-	  val5 = 4.0 /1.0e-15 * M_PI * M_PI * val / pow(val3,3)*1.0e30;  
+	  val5 = 4.0 /1.0e-15 * M_PI * M_PI * val / pow(val3,3)*1.0e30;
 	  sprintf(psr->param[ip8].val,"%.2e",val5);
 	  psr->param[ip8].shortVal = val5;
 	  psr->param[ip8].set1 = 1;
 	  psr->param[ip8].derived = 1;
-	  if (pcat_maxSize[ip8] < strlen(psr->param[ip8].val)) pcat_maxSize[ip8]=strlen(psr->param[ip8].val);	  
+	  if (pcat_maxSize[ip8] < strlen(psr->param[ip8].val)) pcat_maxSize[ip8]=strlen(psr->param[ip8].val);
 	}
     }
   else if (type==7 || type==8) /* PML and PMB */
@@ -449,15 +449,15 @@ void definePM(pulsar *psr,int ip,int type)
 	  val3 = psr->param[ip3].shortVal;
 	  val4 = psr->param[ip4].shortVal;
 	  val5 = psr->param[ip5].shortVal;
-	  
+
 	  sscanf(psr->param[ip1].err,"%d",&ierr1);
-	  sscanf(psr->param[ip2].err,"%d",&ierr2);	      
+	  sscanf(psr->param[ip2].err,"%d",&ierr2);
 	  err1 = psr->param[ip1].error_expand*ierr1;
 	  err2 = psr->param[ip2].error_expand*ierr2;
 
 	  /* Have pmra (val1), pmdec (val2), rajd (val3) and decjd (val4) */
 	  /* Must calculate pml and pmb using hla93 method                */
-	  /* dist = val5                                                  */	 
+	  /* dist = val5                                                  */
 	  if (ecliptic==0) find_galcoord_equatorial(val3*M_PI/180.0,val4*M_PI/180.0,val1,err1,val2,err2,
 					 val5,&mul,&mulerr,&mub,&muberr);
 	  else find_galcoord_ecliptic(val3*M_PI/180.0,val4*M_PI/180.0,val1,err1,val2,err2,
@@ -511,7 +511,7 @@ void defineEquatorial(pulsar *psr,int ip,int type)
   char rajC[500],decjC[500],sdummy[100],sd2[100];
   char msg[1024];
   int lv,le,ierr2;
-  
+
   if (type==1) /* RAJ/DECJ */
     {
       ip1 = getParam("RAJD",NULL);
@@ -526,9 +526,9 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 	{
 	  el = psr->param[ip3].shortVal; /* Elong */
 	  eb = psr->param[ip4].shortVal; /* Elat  */
-	  sscanf(psr->param[ip3].err,"%d",&ierr);	      
+	  sscanf(psr->param[ip3].err,"%d",&ierr);
 	  ele = psr->param[ip3].error_expand*ierr;
-	  sscanf(psr->param[ip4].err,"%d",&ierr);	      
+	  sscanf(psr->param[ip4].err,"%d",&ierr);
 	  ebe = psr->param[ip4].error_expand*ierr;
 	  val3 = psr->param[ip5].shortVal;
 
@@ -539,8 +539,8 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 	  ra = atan2(sin_ra,cos_ra); /* in radians */
 	  /* Get RA into range 0 to 360 */
 	  if (ra < 0.0) ra = 2*M_PI+ra;
-	  else if (ra > 2*M_PI) ra = ra - 2*M_PI; 
-	  
+	  else if (ra > 2*M_PI) ra = ra - 2*M_PI;
+
 	  ddb = 1.0/sqrt(1.0-sdec*sdec)*(cos(eb*dr)*ce - sin(eb*dr)*sin(el*dr)*se);
 	  ddl = 1.0/sqrt(1.0-sdec*sdec)*cos(eb*dr)*cos(el*dr)*se;
 	  dece = sqrt(ddb*ddb*ebe*ebe + ddl*ddl*ele*ele)*dr;
@@ -548,7 +548,7 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 	  k = asin(g);
 	  y = cos(k);
 	  z = 1.0/y;
-	  
+
 	  dzdl = sin(k)/y/y*cos(eb*dr)*se*cos(el*dr)/sqrt(1.0-g*g);
 	  dzdb = sin(k)/y/y*1.0/sqrt(1.0-g*g)*(cos(eb*dr)*ce-sin(eb*dr)*se*sin(el*dr));
 	  dal = -1.0/sqrt(1.0-cos(ra)*cos(ra))*(-cos(eb*dr)*sin(el*dr)*z +
@@ -556,33 +556,33 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 
 	  dab = -1.0/sqrt(1.0-cos(ra)*cos(ra))*(-cos(el*dr)*sin(eb*dr)*z +
 						cos(el*dr)*cos(eb*dr)*dzdb);
-	  
-	  rae = sqrt(dab*dab*ebe*ebe + dal*dal*ele*ele)*dr; 
+
+	  rae = sqrt(dab*dab*ebe*ebe + dal*dal*ele*ele)*dr;
 	  //	  printf("At this point with %g %g %g %g\n",ele,ebe,rae,dece);
 	  /* Now have raj, decj in radians (note rae and dece are in degrees) */
-	  
-	  /* Set rajd and decjd */	 
+
+	  /* Set rajd and decjd */
 	  rnd8(ra/dr,rae/dr,1,psr->param[ip1].val,&lv,psr->param[ip1].err,&le,msg);
 	  psr->param[ip1].shortVal = ra/dr;
 	  sscanf(psr->param[ip1].err,"%d",&ierr2);
 	  psr->param[ip1].error_expand = rae/dr/ierr2;
-	  
+
 	  rnd8(dec/dr,dece/dr,1,psr->param[ip2].val,&lv,psr->param[ip2].err,&le,msg);
 	  psr->param[ip2].shortVal = dec/dr;
 	  sscanf(psr->param[ip2].err,"%d",&ierr2);
 	  psr->param[ip2].error_expand = dece/dr/ierr2;
 
 	  //	  printf("Error = %g %g %g %d\n",rae,dece,dr,ierr2);
-	  
-	  // psr->param[ip1].set1 = 1; psr->param[ip1].shortVal = ra/dr; sprintf(psr->param[ip1].val,"%-10.5f",ra/dr);      
-	  // psr->param[ip2].set1 = 1; psr->param[ip2].shortVal = dec/dr; sprintf(psr->param[ip2].val,"%-10.5f",dec/dr);        
+
+	  // psr->param[ip1].set1 = 1; psr->param[ip1].shortVal = ra/dr; sprintf(psr->param[ip1].val,"%-10.5f",ra/dr);
+	  // psr->param[ip2].set1 = 1; psr->param[ip2].shortVal = dec/dr; sprintf(psr->param[ip2].val,"%-10.5f",dec/dr);
 	  psr->param[ip1].derived = 1;	  psr->param[ip2].derived = 1;
 	  psr->param[ip1].set2 = 1;	  psr->param[ip2].set2 = 1;
 	  if (pcat_maxSize[ip1] < strlen(psr->param[ip1].val)) pcat_maxSize[ip1]=strlen(psr->param[ip1].val);
-	  if (pcat_maxSize[ip2] < strlen(psr->param[ip2].val)) pcat_maxSize[ip2]=strlen(psr->param[ip2].val);  
+	  if (pcat_maxSize[ip2] < strlen(psr->param[ip2].val)) pcat_maxSize[ip2]=strlen(psr->param[ip2].val);
 	  pcat_errZero[ip1] = 1;
 	  pcat_errZero[ip2] = 1;
-	  
+
 	  /* Now calculate raj and decj */
 	  turn_dms(dec/2.0/M_PI,decjC);
 	  turn_hms(ra/2.0/M_PI,rajC);
@@ -591,7 +591,7 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 	  // George converting to degrees --- 24 April 2020
 	  dece /= dr;
 	  rae  /= dr;
-	  
+
 	  /* DECJ */
 	  dp = nearInt(log10(dece*3600.0));
 	  if (dp <= 0)
@@ -630,7 +630,7 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 		  }
 		else
 		  {
-		    decjC[i-dp+1]='\0'; 
+		    decjC[i-dp+1]='\0';
 		  }
 		break;
 	      }
@@ -657,10 +657,10 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 
 	  psr->param[ip7].set1 = 1; strcpy(psr->param[ip7].val,decjC);
 	  psr->param[ip7].set2 = 1; sprintf(psr->param[ip7].err,"%d",err);
-	  if (psr->param[ip3].set3 == 1) {psr->param[ip7].set3 = 1; 
+	  if (psr->param[ip3].set3 == 1) {psr->param[ip7].set3 = 1;
 	  strcpy(psr->param[ip7].ref,psr->param[ip3].ref); pcat_refZero[ip7]=-1;}
 	  psr->param[ip7].error_expand = dece*3600.0/(double)err;
-	  psr->param[ip7].derived = 1;	  
+	  psr->param[ip7].derived = 1;
 	  pcat_errZero[ip7]=-1;
 	  if (pcat_maxSize[ip7] < strlen(psr->param[ip7].val)) pcat_maxSize[ip7]=strlen(psr->param[ip7].val);
 
@@ -706,7 +706,7 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 		  }
 		else
 		  {
-		    rajC[i-dp+1]='\0'; 
+		    rajC[i-dp+1]='\0';
 		  }
 		break;
 	      }
@@ -734,16 +734,16 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 
 	  psr->param[ip6].set1 = 1; strcpy(psr->param[ip6].val,rajC+1);
 	  psr->param[ip6].set2 = 1; sprintf(psr->param[ip6].err,"%d",err);
-	  if (psr->param[ip3].set3 == 1) {psr->param[ip6].set3 = 1; 
+	  if (psr->param[ip3].set3 == 1) {psr->param[ip6].set3 = 1;
 	  strcpy(psr->param[ip6].ref,psr->param[ip3].ref); pcat_refZero[ip6]=-1;}
 	  psr->param[ip6].error_expand = rae*3600.0/15.0/(double)err;
-	  psr->param[ip6].derived = 1;	  
+	  psr->param[ip6].derived = 1;
 	  pcat_errZero[ip6]=-1;
-	  if (pcat_maxSize[ip6] < strlen(psr->param[ip6].val)) 
+	  if (pcat_maxSize[ip6] < strlen(psr->param[ip6].val))
 	    pcat_maxSize[ip6]=strlen(psr->param[ip6].val);
 
-	  //	  printf("Have %s (%f) %d %d %s \n",rajC,rae*3600.0/15.0,dp,err,decjC,dece*3600.0); 
-	} 
+	  //	  printf("Have %s (%f) %d %d %s \n",rajC,rae*3600.0/15.0,dp,err,decjC,dece*3600.0);
+	}
     }
   else if (type==2) /* PMRA PMDEC */
     {
@@ -751,7 +751,7 @@ void defineEquatorial(pulsar *psr,int ip,int type)
       double elong,elat;
       double e_pmra,e_pmdec;
       double epsilon = 84381.4059/60./60.*M_PI/180.;
-      
+
       ip1 = getParam("PMRA",NULL);
       ip2 = getParam("PMDEC",NULL);
       ip3 = getParam("PMELONG",NULL);
@@ -764,29 +764,29 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 	{
 	  double c1,c2,cosb;
 	  double raj,decj;
-	  
+
 	  pmel = psr->param[ip3].shortVal; /* PMElong */
 	  pmeb = psr->param[ip4].shortVal; /* PMElat  */
-	  sscanf(psr->param[ip3].err,"%d",&ierr);	      
+	  sscanf(psr->param[ip3].err,"%d",&ierr);
 	  pmele = psr->param[ip3].error_expand*ierr;
-	  sscanf(psr->param[ip4].err,"%d",&ierr);	      
+	  sscanf(psr->param[ip4].err,"%d",&ierr);
 	  pmebe = psr->param[ip4].error_expand*ierr;
 	  val3 = psr->param[ip5].shortVal;
 
 	  elong = psr->param[ip6].shortVal*M_PI/180.0;
 	  elat = psr->param[ip7].shortVal*M_PI/180.0;
-	  
+
 	  c1 = cos(elat)*cos(epsilon)-sin(elat)*sin(epsilon)*sin(elong);
 	  c2 = -sin(epsilon)*cos(elong);
 	  cosb = sqrt(c1*c1+c2*c2);
-	  
+
 	  pmra   = 1.0/cosb * (c1*pmel+c2*pmeb);
 	  pmdec  = 1.0/cosb * (-c2*pmel+c1*pmeb);
 	  e_pmra = sqrt(pow(c1*pmele/cosb,2) + pow(c2*pmebe/cosb,2));
 	  e_pmdec = sqrt(pow(c2*pmele/cosb,2) + pow(c1*pmebe/cosb,2));
 
 	  //	  printf("Here with pmra = %g +/- %g pmdec = %g +/- %g\n",pmra,e_pmra,pmdec,e_pmdec);
-	  
+
 	  rnd8(pmra,e_pmra,1,psr->param[ip1].val,&lv,psr->param[ip1].err,&le,msg);
 	  psr->param[ip1].shortVal = pmra;
 	  sscanf(psr->param[ip1].err,"%d",&ierr2);
@@ -801,10 +801,10 @@ void defineEquatorial(pulsar *psr,int ip,int type)
 	  psr->param[ip1].set1 = 1;	  psr->param[ip2].set1 = 1;
 	  psr->param[ip1].set2 = 1;	  psr->param[ip2].set2 = 1;
 	  if (pcat_maxSize[ip1] < strlen(psr->param[ip1].val)) pcat_maxSize[ip1]=strlen(psr->param[ip1].val);
-	  if (pcat_maxSize[ip2] < strlen(psr->param[ip2].val)) pcat_maxSize[ip2]=strlen(psr->param[ip2].val);  
+	  if (pcat_maxSize[ip2] < strlen(psr->param[ip2].val)) pcat_maxSize[ip2]=strlen(psr->param[ip2].val);
 	  pcat_errZero[ip1] = 1;
 	  pcat_errZero[ip2] = 1;
-	  
+
 	}
     }
 }
@@ -818,7 +818,7 @@ void defineEcliptic(pulsar *psr,int ip,int type)
   double val,val1,val2,val3,elong,elat;
   double deg2rad = M_PI/180.0;
 
-  if (type==1) /* ELONG/ELAT */    
+  if (type==1) /* ELONG/ELAT */
     {
       ip1 = getParam("RAJD",psr);
       ip2 = getParam("DECJD",psr);
@@ -838,8 +838,8 @@ void defineEcliptic(pulsar *psr,int ip,int type)
 	  /*	  slaEqecl(val1,val2,val3,&elong,&elat); */
 	  elong/=deg2rad;
 	  elat/=deg2rad;
-	  psr->param[ip3].set1 = 1; psr->param[ip3].shortVal = elong; sprintf(psr->param[ip3].val,"%-6.2f",elong);      
-	  psr->param[ip4].set1 = 1; psr->param[ip4].shortVal = elat; sprintf(psr->param[ip4].val,"%-6.2f",elat);        
+	  psr->param[ip3].set1 = 1; psr->param[ip3].shortVal = elong; sprintf(psr->param[ip3].val,"%-6.2f",elong);
+	  psr->param[ip4].set1 = 1; psr->param[ip4].shortVal = elat; sprintf(psr->param[ip4].val,"%-6.2f",elat);
 	  psr->param[ip3].derived = 1;	  psr->param[ip4].derived = 1;
 	  if (pcat_maxSize[ip3] < strlen(psr->param[ip3].val)) pcat_maxSize[ip3]=strlen(psr->param[ip3].val);
 	  if (pcat_maxSize[ip4] < strlen(psr->param[ip4].val)) pcat_maxSize[ip4]=strlen(psr->param[ip4].val);
@@ -855,25 +855,25 @@ void defineGalactic(pulsar *psr,int ip,int type)
   double val,val1,val2,val3,gl,gb;
   double deg2rad = M_PI/180.0;
 
-  if (type==1) /* GL/GB */    
+  if (type==1) /* GL/GB */
     {
       ip1 = getParam("RAJD",psr);
       ip2 = getParam("DECJD",psr);
       ip3 = getParam("GL",NULL);
       ip4 = getParam("GB",NULL);
-      
+
       if (psr->param[ip1].set1==1 && psr->param[ip2].set1==1)
 	{
 	  val1 = psr->param[ip1].shortVal*deg2rad;
 	  val2 = psr->param[ip2].shortVal*deg2rad;
-	  
-	  /*	  sla_eqgal_(&val1,&val2,&gl,&gb); */  /* Call SLALIB routine to convert to gl,gb */ 
+
+	  /*	  sla_eqgal_(&val1,&val2,&gl,&gb); */  /* Call SLALIB routine to convert to gl,gb */
 	  convertGalactic(val1,val2,&gl,&gb);
 	  /*	  slaEqgal(val1,val2,&gl,&gb);*/
 	  gl/=deg2rad;
 	  gb/=deg2rad;
-	  psr->param[ip3].set1 = 1; psr->param[ip3].shortVal = gl; sprintf(psr->param[ip3].val,"%-9.3f",gl);        
-	  psr->param[ip4].set1 = 1; psr->param[ip4].shortVal = gb; sprintf(psr->param[ip4].val,"%-9.3f",gb);        
+	  psr->param[ip3].set1 = 1; psr->param[ip3].shortVal = gl; sprintf(psr->param[ip3].val,"%-9.3f",gl);
+	  psr->param[ip4].set1 = 1; psr->param[ip4].shortVal = gb; sprintf(psr->param[ip4].val,"%-9.3f",gb);
 	  psr->param[ip3].derived = 1;	  psr->param[ip4].derived = 1;
 	  if (pcat_maxSize[ip3] < strlen(psr->param[ip3].val)) pcat_maxSize[ip3]=strlen(psr->param[ip3].val);
 	  if (pcat_maxSize[ip4] < strlen(psr->param[ip4].val)) pcat_maxSize[ip4]=strlen(psr->param[ip4].val);
@@ -889,7 +889,7 @@ void defineGalactic(pulsar *psr,int ip,int type)
 
       val3 = psr->param[ip3].shortVal;
       val  = val3*sin(val2);
-      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.3f",val);        
+      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.3f",val);
       psr->param[ip].derived = 1;
       if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
@@ -903,7 +903,7 @@ void defineGalactic(pulsar *psr,int ip,int type)
 
       val3 = psr->param[ip3].shortVal;
       val  = val3*cos(val2)*sin(val1);
-      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.3f",val);        
+      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.3f",val);
       psr->param[ip].derived = 1;
       if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
@@ -917,7 +917,7 @@ void defineGalactic(pulsar *psr,int ip,int type)
 
       val3 = psr->param[ip3].shortVal;
       val  = 8.5 - val3*cos(val2)*cos(val1);
-      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.3f",val);        
+      psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.3f",val);
       psr->param[ip].derived = 1;
       if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
@@ -928,9 +928,9 @@ void defineGalactic(pulsar *psr,int ip,int type)
       if (psr->param[ip1].set1 == 1){
 	val1 = psr->param[ip1].shortVal;
 	val2 = psr->param[ip2].shortVal*deg2rad;
-	
+
 	val = val1*sin(val2);
-	psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.2f",val);        
+	psr->param[ip].set1 = 1; psr->param[ip].shortVal = val; sprintf(psr->param[ip].val,"%-6.2f",val);
 	psr->param[ip].derived = 1;
 	if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
       }
@@ -945,13 +945,13 @@ void defineDistance(pulsar *psr,int ip,int type)
   int ip1,ip2,ip3,ip4,ip5;
   double val,val1,val2,val3,val4;
   double sigma=-1;
-  /* Calculate dist */
-  /* -- if dist_a exists then use dist_a */
-  /* -- if PX exists then use 1/PX if PX is >3 sigma significance (updated June 3rd 2012: GH)*/
-  /* -- if dist_amn and dist_amx exist and dist_dm lies within boundary */
-  /*      then use dist_dm else use the closest limit to dist_dm */
-  /*  - if dist_dm is not defined then use (dism_amn + dist_amx)/2
-  /* -- otherwise use dist_dm */
+  /* Calculate dist 
+     -- if dist_a exists then use dist_a 
+     -- if PX exists then use 1/PX if PX is >3 sigma significance (updated June 3rd 2012: GH)
+     -- if dist_amn and dist_amx exist and dist_dm lies within boundary
+          then use dist_dm else use the closest limit to dist_dm
+     -- if dist_dm is not defined then use (dism_amn + dist_amx)/2
+     -- otherwise use dist_dm */
 
   ip1 = getParam("PX",NULL);
   ip2 = getParam("DIST_A",NULL);
@@ -998,15 +998,15 @@ void defineDistance(pulsar *psr,int ip,int type)
     }
   else if (psr->param[ip5].set1==1) /* Have DIST_DM or DIST_DM1*/
     val = psr->param[ip5].shortVal;
-  else 
+  else
     return;
 
   psr->param[ip].set1 = 1;
   psr->param[ip].derived = 1;
   psr->param[ip].shortVal = val;
-  sprintf(psr->param[ip].val,"%-6.3f",val);        
+  sprintf(psr->param[ip].val,"%-6.3f",val);
   if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
-    
+
 }
 
 /* ****************************** */
@@ -1024,7 +1024,7 @@ void derive_basedP(pulsar *psr,int ip,int type)
   v1 = psr->param[p0].shortVal;
   v2 = psr->param[p1].shortVal;
 
-  if (v2 <= 0) /* Bad value for Pdot */ 
+  if (v2 <= 0) /* Bad value for Pdot */
     return;
 
   if (type==1 && v2>0)      /* Characteristic age (in years) */
@@ -1060,7 +1060,7 @@ void derive_basedP(pulsar *psr,int ip,int type)
       // only calculate EDOTD2 if values for both DIST AND EDOT exist
       if (v4 != 0.0) {
 
-        /*      v3 = PSR_INERTIA/3.086e21/3.086e21 * 4.0 * (M_PI * M_PI) * 
+        /*      v3 = PSR_INERTIA/3.086e21/3.086e21 * 4.0 * (M_PI * M_PI) *
                 v2 / 4.0 / M_PI / pow(v1,3.0)/(v4*v4);  */
         /* In units of erg kpc-2 s-1 */
         v3 = PSR_INERTIA * 4.0 * M_PI * M_PI * v2 / pow(v1,3.0)/(v4*v4);
@@ -1073,7 +1073,7 @@ void derive_basedP(pulsar *psr,int ip,int type)
         return;
       }
     }
-  
+
   psr->param[ip].set1 = 1;
   psr->param[ip].derived = 1;
   if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) pcat_maxSize[ip]=strlen(psr->param[ip].val);
@@ -1087,14 +1087,14 @@ void derive_basedP(pulsar *psr,int ip,int type)
 /* ********************* */
 void defineDegrees(pulsar *psr,int ip,int type)
 {
-  double val;  
+  double val;
   double err,eval;
   int    ip_raj,ip_decj,ipv,i;
   int ierr1,ierr2;
   int nc;
   char str1[1024],str2[1024],msg[1024];
   int lv,le;
-  
+
   if (psr->param[ip].set1==0)
     {
       if (type==1) {ip_raj  = getParam("RAJ",NULL);  ipv = ip_raj;}
@@ -1105,7 +1105,7 @@ void defineDegrees(pulsar *psr,int ip,int type)
       sprintf(psr->param[ip].val,"%-10.5f",val);
       psr->param[ip].set1 = 1;
       psr->param[ip].derived = 1;
-      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) 
+      if (pcat_maxSize[ip] < strlen(psr->param[ip].val))
 	pcat_maxSize[ip]=strlen(psr->param[ip].val);
 
       //      printf("pcatErrZero = %d %d\n",pcat_errZero[ipv],pcat_errZero[ip]);
@@ -1124,11 +1124,11 @@ void defineDegrees(pulsar *psr,int ip,int type)
 	  if (nc > 2)
 	    {
 	      int iname = getParam("PSRJ",NULL);
-	      printf("WARNING: Have too many colons in RA/DEC string for pulsar %s\n",psr->param[iname].val); 
+	      printf("WARNING: Have too many colons in RA/DEC string for pulsar %s\n",psr->param[iname].val);
 	    }
 	  eval = ierr1*psr->param[ipv].error_expand;
 	  //	  printf("Error for %s (%.5f) ierr1 = %d (%g) ip_err = [%s] (%g)\n",psr->param[ipv].val,val,ierr1,psr->param[ipv].error_expand,psr->param[ip].err,psr->param[ip].error_expand);
-	  
+
 	  // Declination
 	  if (type==2)
 	    {
@@ -1146,7 +1146,7 @@ void defineDegrees(pulsar *psr,int ip,int type)
 	  //	  printf("Input = %g %g\n",val,err);
 	  rnd8(val,err,1,psr->param[ip].val,&lv,psr->param[ip].err,&le,msg);
 	  //	  printf("Output = %s %d %s %d\n",str1,lv,str2,le);
-	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) 
+	  if (pcat_maxSize[ip] < strlen(psr->param[ip].val))
 	    pcat_maxSize[ip]=strlen(psr->param[ip].val);
 
 	  psr->param[ip].set2 = 1;
@@ -1158,8 +1158,8 @@ void defineDegrees(pulsar *psr,int ip,int type)
       else
 	psr->param[ip].set2 = 0;
 
-      
-    }  
+
+    }
 }
 
 /* ************************ */
@@ -1175,7 +1175,7 @@ void defineBinary(pulsar *psr,int ip,int type)
   int ip2,ip3;
 
   if (psr->param[ip].set1==0)
-    {     
+    {
       if (type==1 || type==2 || type==3 || type==4) /* MASSFN/MINMASS/MEDMASS/UPMASS */
 	{
 	  ip1 = getParam("A1",NULL);
@@ -1183,7 +1183,7 @@ void defineBinary(pulsar *psr,int ip,int type)
 	  if (psr->param[ip1].set1==1 && psr->param[ip2].set1==1)
 	    {
 	      pb    = psr->param[ip2].shortVal*day2sec;
-	      asini = psr->param[ip1].shortVal*speedlight; 
+	      asini = psr->param[ip1].shortVal*speedlight;
 	      massfn = 2.0*M_PI*2.0*M_PI/gm*pow(asini,3)/pb/pb;
 
 	      if (type==1) /* MASSFN */
@@ -1208,8 +1208,8 @@ void defineBinary(pulsar *psr,int ip,int type)
 		}
 	      psr->param[ip].set1 = 1;
 	      psr->param[ip].derived = 1;
-	      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) 
-		pcat_maxSize[ip]=strlen(psr->param[ip].val);	      
+	      if (pcat_maxSize[ip] < strlen(psr->param[ip].val))
+		pcat_maxSize[ip]=strlen(psr->param[ip].val);
 	    }
 	}
       if (type==5 || type==6) /* OM/ECC from EPS1 and EPS2 if ELL1 model */
@@ -1221,14 +1221,14 @@ void defineBinary(pulsar *psr,int ip,int type)
 	      eps1 = psr->param[ip1].shortVal;
 	      eps2 = psr->param[ip2].shortVal;
 	      sscanf(psr->param[ip1].err,"%d",&ierr_eps1);
-	      sscanf(psr->param[ip2].err,"%d",&ierr_eps2);	      
+	      sscanf(psr->param[ip2].err,"%d",&ierr_eps2);
 	      err1 = psr->param[ip1].error_expand*ierr_eps1;
 	      err2 = psr->param[ip2].error_expand*ierr_eps2;
 	      val2 = sqrt(pow(eps1,2)+pow(eps2,2)); /* ECC */
 	      if (type==5 && val2 != 0.0) /* OM */
 		{
 		  val  = atan2(eps1,eps2)*180.0/M_PI;
-		  err  = pow(pow(eps2*err1,2)+pow(eps1*err2,2),0.5)/val2/val2*180.0/M_PI;		  
+		  err  = pow(pow(eps2*err1,2)+pow(eps1*err2,2),0.5)/val2/val2*180.0/M_PI;
 		  if (val<0) val+=360.0;
 		  rnd8(val,err,1,psr->param[ip].val,&lv,psr->param[ip].err,&le,msg);
 		  psr->param[ip].shortVal = val;
@@ -1242,18 +1242,18 @@ void defineBinary(pulsar *psr,int ip,int type)
 		  else
 		    err = pow(pow(eps1*err1,2)+pow(eps2*err2,2),0.5)/val;
 		  rnd8(val,err,1,psr->param[ip].val,&lv,psr->param[ip].err,&le,msg);
-		  psr->param[ip].shortVal = val;		  
+		  psr->param[ip].shortVal = val;
 		}
 	      if (val2!=0.0)
 		{
-		  strcpy(psr->param[ip].ref,psr->param[ip1].ref); 
-		  
+		  strcpy(psr->param[ip].ref,psr->param[ip1].ref);
+
 		  psr->param[ip].set1 = 1;
 		  psr->param[ip].set2 = 1;
 		  psr->param[ip].set3 = 1;
 		  psr->param[ip].derived = 1;
-		  if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) 
-		    pcat_maxSize[ip]=strlen(psr->param[ip].val);	      
+		  if (pcat_maxSize[ip] < strlen(psr->param[ip].val))
+		    pcat_maxSize[ip]=strlen(psr->param[ip].val);
 		}
 	      else
 		psr->param[ip].set1 = 0;
@@ -1271,20 +1271,20 @@ void defineBinary(pulsar *psr,int ip,int type)
 	      val1 = psr->param[ip1].shortVal; /* ECC */
 	      val2 = psr->param[ip2].shortVal*day2sec; /* PB  */
 	      val3 = psr->param[ip3].shortVal; /* MINMASS  */
-	      val = 3.0*		
+	      val = 3.0*
 		pow(2.0*M_PI/val2*day2sec/86400.0, 5.0/3.0)*
 		pow((MASS_PSR+val3)*4.925490946e-6, 2.0/3.0)/
 		(1.0-val1*val1)*
 		180.0/M_PI*          /* rad/sec --> deg/sec */
-		86400.0*365.25;      /* deg/sec --> deg/yr */	      
-	      sprintf(psr->param[ip].val,"%10.3g",val);	      
+		86400.0*365.25;      /* deg/sec --> deg/yr */
+	      sprintf(psr->param[ip].val,"%10.3g",val);
 	      psr->param[ip].set1 = 1;
 	      psr->param[ip].derived = 1;
-	      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) 
-		pcat_maxSize[ip]=strlen(psr->param[ip].val);	      
+	      if (pcat_maxSize[ip] < strlen(psr->param[ip].val))
+		pcat_maxSize[ip]=strlen(psr->param[ip].val);
 	    }
 	}
-    }  
+    }
 }
 
 /* ************************ */
@@ -1296,16 +1296,16 @@ void defineCustom(pulsar *psr,int ip,int type,int exactMatch)
   int badval;
 
   if (strlen(pcat_custom1)<10 && type==1)
-    { printf("Custom parameter 1 not defined\n"); exit(1); } 
+    { printf("Custom parameter 1 not defined\n"); exit(1); }
   else if (strlen(pcat_custom2)<10 && type==2)
-    { printf("Custom parameter 2 not defined\n"); exit(1); } 
+    { printf("Custom parameter 2 not defined\n"); exit(1); }
   else if (strlen(pcat_custom3)<10 && type==3)
-    { printf("Custom parameter 3 not defined\n"); exit(1); } 
+    { printf("Custom parameter 3 not defined\n"); exit(1); }
   else if (strlen(pcat_custom4)<10 && type==4)
-    { printf("Custom parameter 4 not defined\n"); exit(1); } 
+    { printf("Custom parameter 4 not defined\n"); exit(1); }
 
   psr->param[ip].set1 = 0;
-  
+
   if (type==1) psr->param[ip].shortVal = v1 = formExpression(pcat_custom1,psr,&badval,exactMatch);
   if (type==2) psr->param[ip].shortVal = v1 = formExpression(pcat_custom2,psr,&badval,exactMatch);
   if (type==3) psr->param[ip].shortVal = v1 = formExpression(pcat_custom3,psr,&badval,exactMatch);
@@ -1315,25 +1315,25 @@ void defineCustom(pulsar *psr,int ip,int type,int exactMatch)
       sprintf(psr->param[ip].val,CUSTOM_FORMAT,v1);
       psr->param[ip].set1 = 1;
       psr->param[ip].derived = 1;
-      if (pcat_maxSize[ip] < strlen(psr->param[ip].val)) 
+      if (pcat_maxSize[ip] < strlen(psr->param[ip].val))
 	pcat_maxSize[ip]=strlen(psr->param[ip].val);
     }
 }
 
 double turn_deg(double turn){
- 
+
   /* Converts double turn to string "sddd.ddd" */
   return turn*360.0;
 }
 
 int turn_dms(double turn, char *dms){
-  
+
   /* Converts double turn to string "sddd:mm:ss.sss" */
-  
+
   int dd, mm, isec;
   double trn, sec;
   char sign;
-  
+
   sign=' ';
   if (turn < 0.){
     sign = '-';
@@ -1356,14 +1356,15 @@ int turn_dms(double turn, char *dms){
       }
     }
   sprintf(dms,"%c%02d:%02d:%010.7f",sign,dd,mm,sec);
- 
+
+  return 0;
 }
 
 
 int turn_hms(double turn, char *hms){
- 
+
   /* Converts double turn to string " hh:mm:ss.ssss" */
-  
+
   int hh, mm, isec;
   double sec;
 
@@ -1384,14 +1385,15 @@ int turn_hms(double turn, char *hms){
     }
 
   sprintf(hms," %02d:%02d:%010.7f",hh,mm,sec);
- 
+
+  return 0;
 }
 
 
 double hms_turn(char *line){
 
   /* Converts string " hh:mm:ss.ss" or " hh mm ss.ss" to double turn */
-  
+
   int i;int turn_hms(double turn, char *hms);
   double hr, min, sec, turn=0;
   char hold[MAX_STRLEN];
@@ -1418,7 +1420,7 @@ double hms_turn(char *line){
 double dms_turn(char *line){
 
   /* Converts string "-dd:mm:ss.ss" or " -dd mm ss.ss" to double turn */
-  
+
   int i;
   char *ic, ln[40];
   double deg, min, sec, sign, turn=0;
@@ -1499,19 +1501,19 @@ unsigned long int encode_survey( char * inptr,int survey_num,char surveynames[MA
   char * survnam=NULL;
 
   /* Modified by G. Hobbs (13/01/03), Surveys now deliminated by ',' not white space */
-  for(survnam=strtok(inptr,",\n"); survnam != NULL; 
-      survnam=strtok(NULL,",\n")) 
-    {    
+  for(survnam=strtok(inptr,",\n"); survnam != NULL;
+      survnam=strtok(NULL,",\n"))
+    {
       imask = 1;
       i = 0;
       found = 0;
-      while( i <= survey_num && strcmp(survnam,surveynames[i++]) != 0 ) 
+      while( i <= survey_num && strcmp(survnam,surveynames[i++]) != 0 )
 	{
 	  imask <<= 1LL;
 	}
       if (strcmp(survnam,surveynames[i-1])==0)found=1;
       if( found==0)
-	{ 
+	{
 	  printf("unknown survey : %s (please contact the ATNF if this survey should be entered into the psrcat survey list)\n",survnam);
 	}
       else
@@ -1564,13 +1566,20 @@ int define_surveys(char surveynames[MAX_STRLEN][MAX_SURVEYS])
   strcpy(surveynames[29],"ghrss");
   strcpy(surveynames[30],"pks_superb");
   strcpy(surveynames[31],"lotaas");
-  strcpy(surveynames[32],"fast_uwb");
+  strcpy(surveynames[32],"fast_crafts");
   strcpy(surveynames[33],"fast_gpps");
   strcpy(surveynames[34],"chime");
   strcpy(surveynames[35],"meerkat_trapum");
-  strcpy(surveynames[36],"fast_mb");
-  strcpy(surveynames[37],"tulipp");
-  survey_num=37;
+  strcpy(surveynames[36],"tulipp");
+  strcpy(surveynames[37],"mwa_smart");
+  strcpy(surveynames[38],"pumps");
+  strcpy(surveynames[39],"mmgps-l");
+  strcpy(surveynames[40],"gbt820");
+  strcpy(surveynames[41],"fast_hglps");
+  strcpy(surveynames[42],"gcgps");
+  strcpy(surveynames[43],"fast_gcps");
+  strcpy(surveynames[44],"chime_champss");
+  survey_num=44;
   return survey_num;
 }
 
@@ -1580,7 +1589,7 @@ double galpa(double el, double eb){
   float  fgl, fgb, fglpole, fgbpole;
   double eclpole, ecbpole;
   double dgpa;
-  double date,v1,v2; 
+  double date,v1,v2;
   double first,second;
 
   date = 51544.0;
@@ -1600,10 +1609,10 @@ double galpa(double el, double eb){
   /*  sla_eqecl_(&v1,&v2,&date,&eclpole,&ecbpole); */
   /* Get ecliptic PA */
   fgl = el, fgb = eb, fglpole = eclpole, fgbpole = ecbpole;
-  dgpa = posAngle(fgl,fgb,fglpole,fgbpole);   
+  dgpa = posAngle(fgl,fgb,fglpole,fgbpole);
   /*  dgpa = sla_bear_(&fgl,&fgb,&fglpole,&fgbpole);  */
   dgpa = dgpa/(2.0*M_PI)*360.0;            /* Convert to degrees */
- 
+
   return -dgpa;
 }
 
@@ -1624,7 +1633,7 @@ void defineParameters(paramtype *defParam)
   addParameter(defParam,"P1","%8.2e","P1"," ","Period derivative",2,0);
   addParameter(defParam,"DIST_DM","%9.3f","DIST_DM","(kpc)","Distance based on the YMW16 electron density model",4,0);
   addParameter(defParam,"DIST_DM1","%9.3f","DIST_DM1","(kpc)","Distance based on the NE2001 electron density model",4,0);
-  addParameter(defParam,"SURVEY","%-35.35s","SURVEY"," ","Surveys that detected pulsar (discovery survey first)",5,0);
+  addParameter(defParam,"SURVEY","%-55.55s","SURVEY"," ","Surveys that detected pulsar (discovery survey first)",5,0);
   addParameter(defParam,"PMRA","%9.3f","PMRA","(mas/yr)","Proper motion in RA (mas/yr)",1,1);
   addParameter(defParam,"PMDEC","%9.3f","PMDEC","(mas/yr)","Proper motion in DEC (mas/yr)",1,1);
   addParameter(defParam,"S30","%8.2f","S30","(mJy)","Flux at 30MHz (mJy)",2,0);
@@ -1732,7 +1741,7 @@ void defineParameters(paramtype *defParam)
   addParameter(defParam,"ECC_3","%10.5f","ECC_3"," ","Eccentricity [3rd orbit]",3,1);
   addParameter(defParam,"ALIAS","%-s","ALIAS"," ","Pulsar aliases",1,0);
   addParameter(defParam,"DATE","%4.0f","DISC.","DATE","Year of discovery publication",5,0);
-  addParameter(defParam,"DIST","%8.3f","DIST","(kpc)","Best estimate of pulsar distance (kpc)",4,0);  
+  addParameter(defParam,"DIST","%8.3f","DIST","(kpc)","Best estimate of pulsar distance (kpc)",4,0);
   addParameter(defParam,"DIST1","%8.3f","DIST1","(kpc)","Best estimate of pulsar distance, using NE2001 model (kpc)",4,0);
   addParameter(defParam,"PMERR_PA","%9.3f","PMERR_PA","(deg)","Angle for proper motion error ellipse",1,0);
   addParameter(defParam,"BRK_INDX","%10.5f","BRK_INDX"," ","Braking index (observed)",2,0);
@@ -1764,8 +1773,8 @@ void defineParameters(paramtype *defParam)
   addParameter(defParam,"YY","%9.3f","YY","(kpc)","Y-Distance in X-Y-Z Galactic coordinate system (kpc)",4,0);
   addParameter(defParam,"ZZ","%9.3f","ZZ","(kpc)","Distance from the Galactic plane - based on DIST (kpc)",4,0);
   addParameter(defParam,"INTERIM","%-7.7s","INTERIM"," ","Interim parameters only",5,0);
-  addParameter(defParam,"PML","%9.3f","PML      ","(deg/yr)","Proper motion in l (mas/yr)",1,0);
-  addParameter(defParam,"PMB","%9.3f","PMB      ","(deg/yr)","Proper motion in b (mas/yr)",1,0);
+  addParameter(defParam,"PML","%9.3f","PML      ","(mas/yr)","Proper motion in l (mas/yr)",1,0);
+  addParameter(defParam,"PMB","%9.3f","PMB      ","(mas/yr)","Proper motion in b (mas/yr)",1,0);
   addParameter(defParam,"F7","%10.3e","F7","(s^-8)","Seventh time deriv baryctr rotn frequency (s^-8)",2,1);
   addParameter(defParam,"F8","%10.3e","F8","(s^-9)","Eighth time deriv baryctr rotn frequency (s^-9)",2,1);
   addParameter(defParam,"F9","%10.3e","F9","(s^-10)","Ninth time deriv baryctr rotn frequency (s^-10)",2,1);
@@ -1862,7 +1871,7 @@ void addParameter(paramtype *defParam,char *p1,char *p2,char *p3,char *p4,char *
 {
   static unsigned int count=0;
   strcpy(defParam[count].shortStr,p2);
-  if (strstr(p2,"s")==0) 
+  if (strstr(p2,"s")==0)
     defParam[count].numeric=1;
   else
     defParam[count].numeric=0;
@@ -1910,7 +1919,7 @@ void convertEcliptic(double raj,double decj,double *elong,double *elat)
   beta = asin(sinb);
   y = sin(raj)*cos(epsilon)+tan(decj)*sin(epsilon);
   x = cos(raj);
-  
+
   lambdap = atan2(y,x);
   if (lambdap<0) lambda=lambdap+2*M_PI;
   else lambda = lambdap;
@@ -1928,9 +1937,9 @@ void convertGalactic(double raj,double decj,double *gl,double *gb)
   double gpoleDECJ = 27.116*deg2rad;
   double rot[4][4];
 
-  /* Note: Galactic coordinates are defined from B1950 system - e.g. must transform from J2000.0 
+  /* Note: Galactic coordinates are defined from B1950 system - e.g. must transform from J2000.0
      equatorial coordinates to IAU 1958 Galactic coords */
-  
+
   /* Convert to rectangular coordinates */
   rx = cos(raj)*cos(decj);
   ry = sin(raj)*cos(decj);
