@@ -4,12 +4,23 @@
 #include <string.h>
 #include <ctype.h>
 #include "psrcat.h"
- 
-pulsar psr[MAX_PSR]; 
 
-char pcat_parameters[MAX_PARAM][20];  
+pulsar psr[MAX_PSR];
+
+char pcat_parameters[MAX_PARAM][20];
+int  pcat_maxSize[MAX_PARAM];
+int  pcat_refZero[MAX_PARAM];
+int  pcat_errZero[MAX_PARAM];
+int  pcat_sort;
+int  pcat_descend;
+char pcat_custom1[MAX_FILTERSTR];
+char pcat_custom2[MAX_FILTERSTR];
+char pcat_custom3[MAX_FILTERSTR];
+char pcat_custom4[MAX_FILTERSTR];
+int  verbose;
+
 paramtype defParam[MAX_PARAM];
-  
+
 float recordCompare(void const *a,void const *b);
 void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,paramtype *defParam,int ephem,int webflag);
 void mySort(pulsar *psr,linkedList *list,int npsr);
@@ -44,7 +55,7 @@ int main(int argc,char *argv[])
   int noNumber=0,nread;
   int tbForm = 0; /* Long format */
   FILE *groupFile;
-  int aliasCount=0;
+  unsigned int aliasCount=0;
   int debug=0;
   char alias1[MAX_ALIASES][MAX_STRLEN],alias2[MAX_ALIASES][MAX_STRLEN];
   if (debug==1) printf("Starting off\n");
@@ -87,7 +98,7 @@ int main(int argc,char *argv[])
       else
 	strcat(filterStr," !TYPE(INTERIM) ");
     }
-  if (allmerge == 1) 
+  if (allmerge == 1)
     {
       strcat(mergeCat," ");
       /*      mergeit = getenv("PSRCAT_RUNDIR");*/
@@ -107,14 +118,14 @@ int main(int argc,char *argv[])
      /* ISSUE: THESE LINES SHOULD BE SWITCHED FOR SOLARIS AND FOR LINUX */
 
      /* The egrep line is for solaris */
-     if (webflag==0)       
-         sprintf(sysstr,"sed -n -e '/psrj\\|alias\\|PSRJ\\|ALIAS/p' %s | grep -B 1 -i alias | awk '{print $2}'",mergeCat);   
+     if (webflag==0)
+         sprintf(sysstr,"sed -n -e '/psrj\\|alias\\|PSRJ\\|ALIAS/p' %s | grep -B 1 -i alias | awk '{print $2}'",mergeCat);
        /*                   sprintf(sysstr,"/usr/local/gnu/bin/egrep -i \"psrj|alias\" %s | /usr/local/gnu/bin/grep -B 1 -i alias | awk '{print $2}'",mergeCat); */
-     else 
-       sprintf(sysstr,"/usr/local/gnu/bin/egrep -i \"psrj|alias\" %s | /usr/local/gnu/bin/grep -B 1 -i alias | awk '{print $2}'",mergeCat); 
-       //       sprintf(sysstr,"/bin/egrep -i \"psrj|alias\" %s | /usr/local/gnu/bin/grep -B 1 -i alias | awk '{print $2}'",mergeCat); 
-       
-     
+     else
+       sprintf(sysstr,"/usr/local/gnu/bin/egrep -i \"psrj|alias\" %s | /usr/local/gnu/bin/grep -B 1 -i alias | awk '{print $2}'",mergeCat);
+       //       sprintf(sysstr,"/bin/egrep -i \"psrj|alias\" %s | /usr/local/gnu/bin/grep -B 1 -i alias | awk '{print $2}'",mergeCat);
+
+
      if (!(pin = popen(sysstr,"r")))
        printf("Unable to run %s\n",sysstr);
 
@@ -122,7 +133,7 @@ int main(int argc,char *argv[])
 	{
 	  if (fscanf(pin,"%s %s",alias1[aliasCount],alias2[aliasCount])==2)
 	    {
-	      aliasCount++; 
+	      aliasCount++;
 	      if (aliasCount > MAX_ALIASES)
 		{
 		  printf("ERROR: too many aliases\n");
@@ -153,7 +164,7 @@ int main(int argc,char *argv[])
   /* **************************** */
   if (strlen(mergeCat)>0)
     {
-      strptr = strtok_r(mergeCat," ;,\t\n",&savePtr);	  
+      strptr = strtok_r(mergeCat," ;,\t\n",&savePtr);
       while (1)
 	{
 	  /* ****************************** */
@@ -165,7 +176,7 @@ int main(int argc,char *argv[])
 	    {
 	      nread = fscanf(groupFile,"%s",tempMerge);
 
-	      if (nread==1) readCatalogue(psr,list,&npsr,selectNames,iname,haveName,filterStr,ptr,sptr,np,tempMerge,1,1,boundary,defParam,checkCat,alias1,alias2,aliasCount,exactMatch);      	  
+	      if (nread==1) readCatalogue(psr,list,&npsr,selectNames,iname,haveName,filterStr,ptr,sptr,np,tempMerge,1,1,boundary,defParam,checkCat,alias1,alias2,aliasCount,exactMatch);
 	    }
 	  pclose(groupFile);
 	  strptr = strtok_r(NULL," ;,\t\n",&savePtr);
@@ -202,13 +213,13 @@ int main(int argc,char *argv[])
 		{
 		  if (check->param[ptr[j]].set1 != 1)
 		    deriveParameter(sptr[j],check,ptr[j]);
-		} 
+		}
 	    }
 	  check = (temp[i].post)->current;
 	}
       npsr = count;
     }
-  
+
 
   /* Check that all pulsar names given on the command line exist */
   for (i=0;i<iname;i++)
@@ -217,12 +228,12 @@ int main(int argc,char *argv[])
 	{
 	  if (webflag==0)
 	    printf("WARNING: PSR %s not in catalogue\n",selectNames[i]);
-	  else 
-	    printf("<pre>WARNING: PSR %s not in catalogue</pre> \n",selectNames[i]); 
+	  else
+	    printf("<pre>WARNING: PSR %s not in catalogue</pre> \n",selectNames[i]);
 	}
     }
   /* Sort the catalogue */
-  if (pcat_sort!=-1) mySort(psr,list,npsr);   
+  if (pcat_sort!=-1) mySort(psr,list,npsr);
   if (bib_info==1)
     {
       get_bibliography(psr,npsr);
@@ -259,10 +270,10 @@ int main(int argc,char *argv[])
     }
   /* Finish off */
   if (webflag == 1)
-    {   
+    {
       printf("</pre>\n");
       printf("</font>\n");
-    } 
+    }
   return 0;
 }
 
@@ -274,7 +285,7 @@ void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,para
   parameter dispParam;
   int raDecCoords=0; // 0 = not set, 1 equatorial, 2 = ecliptic
   int pmCoords=0;    // 0 = not set, 1 equatorial, 2 = ecliptic
-  
+
   psrptr = list[0].current;
 
   ip2=getParam("ELONG",NULL);
@@ -296,11 +307,9 @@ void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,para
     raDecCoords=1;
   if (psr->param[ip2].set1 == 1 && psr->param[ip3].set1 == 1)
     raDecCoords=2;
-
-  if (psr->param[ip4].set1 == 1 || psr->param[ip5].set1 == 1)
+  if (psr->param[ip4].set1 == 1 || psr->param[ip5].set1 == 1 ||
+      psr->param[ip8].set1 == 1 || psr->param[ip9].set1 == 1)
     pmCoords=1;
-  if (psr->param[ip8].set1 == 1 || psr->param[ip9].set1 == 1)
-    pmCoords=2;
 
   for (i=0;i<npsr;i++)
     {
@@ -330,14 +339,14 @@ void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,para
 		      strcmp(pcat_parameters[j],"C4")!=0)
 		    {
 		      /* Output raj and decj if have elat and elong, but pmra and pmdec */
-		      /*		      if (ip==ip2 && (psrptr->param[ip4].set1==1 
+		      /*		      if (ip==ip2 && (psrptr->param[ip4].set1==1
 				      || psrptr->param[ip5].set2==1))
 			{
 			  ip = ip6;
 			  dispParam = psrptr->param[ip];
 			  strcpy(pcat_parameters[j],"RAJ");
 			}
-		      if (ip==ip3 && (psrptr->param[ip4].set1==1 
+		      if (ip==ip3 && (psrptr->param[ip4].set1==1
 				      || psrptr->param[ip5].set2==1))
 			{
 			  ip = ip7;
@@ -370,7 +379,7 @@ void displayEphemeris(pulsar *psr,linkedList *list,int npsr,int *ptr,int np,para
 			    {
 			      printf("%-15.15s %-30.30s",pcat_parameters[j],dispParam.val);
 			      if (dispParam.set2==1)
-				{			    
+				{
 				  sscanf(dispParam.err,"%d",&ierr);
 				  sprintf(str,"%.3e",dispParam.error_expand*ierr);
 				  printf("%-10.10s",str);
@@ -439,7 +448,7 @@ void mySort(pulsar *psr,linkedList *list,int npsr)
 
 	    list[i].current   = temp1;
 	    change=1;
-	  }	
+	  }
 	psr1 = psr2;
       }
   } while (change==1);
@@ -465,11 +474,11 @@ float recordCompare(void const *a,void const *b)
 
 
   if (s1 != 1 && s2 != 1)
-    return 0; 
+    return 0;
   if (s1 != 1 && s2 == 1)
-    return -1; 
+    return -1;
   if (s1 == 1 && s2 != 1)
-    return 1; 
+    return 1;
 
   if (pcat_descend==1) /* Sort in descending order */
     {
@@ -561,7 +570,7 @@ void listReferences(int flag,char *giveref,pulsar *psr,int npsr,int *ptr,int np)
   int  i,j,k;
 
   //  printf("In here with flag: %d, np = %d\n",flag,np);
-  
+
   if (flag==4)
     {
       fout = fopen("dummy.tex","w");
@@ -601,7 +610,7 @@ void listReferences(int flag,char *giveref,pulsar *psr,int npsr,int *ptr,int np)
   //  printf("Number of references = %d\n",countRef);
   if (getenv("PSRCAT_RUNDIR")==NULL)
     {
-      printf("Warning PSRCAT_RUNDIR not set\n");      
+      printf("Warning PSRCAT_RUNDIR not set\n");
       exit(1);
     }
   strcpy(fname,getenv("PSRCAT_RUNDIR"));
@@ -648,7 +657,7 @@ void listReferences(int flag,char *giveref,pulsar *psr,int npsr,int *ptr,int np)
 	    printf("%s",str);
 	  else if (flag==3  && strcasecmp(ref,giveref)==0)
 	    printf("%s",str);
- 
+
 	}
     }
   if (flag==4)
@@ -668,9 +677,9 @@ void listReferences(int flag,char *giveref,pulsar *psr,int npsr,int *ptr,int np)
 	{
 	  if (fgets(strVal,1000,fin2)!=NULL)
 	    printf("%s",strVal);
-  
+
 	}
-	     
+
 
       printf("</pre>\n");
     }
