@@ -16,10 +16,17 @@ void check_values(char *fline,int *errornum,char *current_psr);
 void check_reference(char* fline,int *errornum,char *current_psr);
 void checkCatalogue(FILE *fin,char *fname);
 
-int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_NAMELEN],
-		  int iname,int *haveName,char *filterStr,int *ptr,char sptr[MAX_PLIST][MAX_STRLEN],int np,
-		  char *dbFile,int merge,int willmerge,char *boundary,paramtype *defParam,int checkCat,
-		  char alias1[MAX_ALIASES][MAX_STRLEN],char alias2[MAX_ALIASES][MAX_STRLEN],int aliasCount,int exactMatch)
+int readCatalogue(pulsar *psr,linkedList *list,int *npsr,
+                  char name[MAX_PSR][MAX_NAMELEN], int iname,int *haveName,
+                  char *filterStr, int *ptr, char sptr[MAX_PLIST][MAX_STRLEN],
+                  int np,
+                  char *dbFile,int merge,int willmerge,
+                  char *boundary,
+                  paramtype *defParam,
+                  int checkCat,
+                  char alias1[MAX_ALIASES][MAX_STRLEN],
+                  char alias2[MAX_ALIASES][MAX_STRLEN],
+                  unsigned int aliasCount,int exactMatch)
 {
   FILE *fin;
   register unsigned int i,j,k,filter;
@@ -102,7 +109,7 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 	      for (i=iname;i--;)
 		{
 		  if (wc_strncmp(name[i],psr[*npsr].param[0].val,-1,0,1)==0 ||  /* Check jname */
-		      (psr[*npsr].param[1].set1 == 1 && 
+		      (psr[*npsr].param[1].set1 == 1 &&
 		       wc_strncmp(name[i],psr[*npsr].param[1].val,-1,0,1)==0)
 		      || (psr[*npsr].param[aliasip].set1 == 1 &&
 			  wc_strncmp(name[i],psr[*npsr].param[aliasip].val,-1,0,1)==0))
@@ -137,10 +144,10 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 		    {
 		      if (psr[*npsr].param[ptr[j]].set1 != 1)
 			deriveParameter(sptr[j],&psr[*npsr],ptr[j]);
-		    } 
+		    }
 		}
 	      if (found==-1)
-		{		  
+		{
 		  (*npsr)++;
 		  maxpsr++;
 		}
@@ -217,7 +224,7 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 			      strcpy(strval,psr[i].param[0].val);
 			      break;
 			    }
-			  
+
 			}
 		      if (found!=-1)
 			{
@@ -226,7 +233,7 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 			}
 		      psr[*npsr].merged=1;
 
-		    }	         
+		    }
 		  if (strcmp(paramLab,"DECJ")==0 || strcmp(paramLab,"RAJ")==0)  /* Check have XX:YY:ZZ.zzz */
 		    {
 		      int ip_elat,ip_elong;
@@ -235,7 +242,7 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 		      ip_elat  = getParam("ELAT",NULL);
 		      if (psr[*npsr].param[ip_elong].set1==1) psr[*npsr].param[ip_elong].set1=0;
 		      if (psr[*npsr].param[ip_elat].set1==1) psr[*npsr].param[ip_elat].set1=0;
-		      
+
 		      for (k=strlen(strval);k>3;k--)
 			{
 			  if (strval[k]=='.' && strval[k-2]==':')
@@ -292,13 +299,13 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 		      ip = getParam("P1",NULL);
 		      if (psr[*npsr].param[ip].set1==1) psr[*npsr].param[ip].set1=0;
 		    }
-		  
+
 		  if (strcmp(paramLab,"DECJ")==0 && strval[0]!='+' && strval[0]!='-')
 		    sprintf(psr[*npsr].param[ival].val,"+%s",strval);
 		  else
 		    strcpy(psr[*npsr].param[ival].val,strval);
 		  sscanf(strval,"%lf",&(psr[*npsr].param[ival].shortVal));
-		  if (psr[*npsr].merged==1 && 
+		  if (psr[*npsr].merged==1 &&
 		      (strcmp(paramLab,"BINARY")==0))
 		    {
 		      /* Clear all standard binary model parameters */
@@ -343,12 +350,12 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 			  strcpy(psr[*npsr].param[eph].val,"2");
 			}
 		    }
-		  if (psr[*npsr].merged==1 && 
+		  if (psr[*npsr].merged==1 &&
 		      (strcmp(paramLab,"PMELAT")==0 || strcmp(paramLab,"PMELONG")==0))
 		    {
 		      ip  = getParam("PMRA",NULL);
 		      ip2 = getParam("PMDEC",NULL);
-		      if (psr[*npsr].param[ip].set1 == 1 || psr[*npsr].param[ip2].set1) 
+		      if (psr[*npsr].param[ip].set1 == 1 || psr[*npsr].param[ip2].set1)
 			{
 			  psr[*npsr].param[ip].shortVal=0.0;
 			  psr[*npsr].param[ip2].shortVal=0.0;
@@ -356,12 +363,12 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 			  psr[*npsr].param[ip2].set1=0;
 			}
 		    }
-		  if (psr[*npsr].merged==1 && 
+		  if (psr[*npsr].merged==1 &&
 		      (strcmp(paramLab,"PMRA")==0 || strcmp(paramLab,"PMDEC")==0))
 		    {
 		      ip  = getParam("PMELAT",NULL);
 		      ip2 = getParam("PMELONG",NULL);
-		      if (psr[*npsr].param[ip].set1 == 1 || psr[*npsr].param[ip2].set1) 
+		      if (psr[*npsr].param[ip].set1 == 1 || psr[*npsr].param[ip2].set1)
 			{
 			  psr[*npsr].param[ip].shortVal=0.0;
 			  psr[*npsr].param[ip2].shortVal=0.0;
@@ -381,19 +388,19 @@ int readCatalogue(pulsar *psr,linkedList *list,int *npsr,char name[MAX_PSR][MAX_
 			{
 			  strcpy(psr[*npsr].param[ival].err,strptr);
 			  /* Form expanded version of the uncertainty */
-			  psr[*npsr].param[ival].error_expand = 
+			  psr[*npsr].param[ival].error_expand =
 			    errscale(strval,psr[*npsr].param[ival].err);
 			  psr[*npsr].param[ival].set2 = 1;
 			  pcat_errZero[ival]=-1;
-			  /* Probably a reference as well ? */		      
-			  
+			  /* Probably a reference as well ? */
+
 			  if ((strptr = strtok(NULL," \t\n")) != NULL)
 			    {
 			      strcpy(psr[*npsr].param[ival].ref,strptr);
 			      psr[*npsr].param[ival].set3 = 1;
 			      pcat_refZero[ival]=-1;
 			    }
-			}		  
+			}
 		      else
 			{
 			  strcpy(psr[*npsr].param[ival].ref,strptr);
@@ -478,9 +485,9 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
   strcpy(storeStr,filterStr);
   /* Search for first occurrence of special characters */
   *badval = 0;
-  do {   
+  do {
     tempptr = strpbrk(storeStr," \t\n()><|!+-*/%&=^~;,");
-    if (tempptr!=NULL) 
+    if (tempptr!=NULL)
       {
 	strcpy(storeCharstr,tempptr);
 	storeCharstr[1] = '\0';
@@ -498,7 +505,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	if ((ip = getParam(storeStr,psr))==-1)
 	  {
 	    *badval=1;
-	    return 0; 
+	    return 0;
 	  }
 	if (psr->param[ip].set1==1)
 	  strcat(newstr,"1");
@@ -563,10 +570,10 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 		      }
 		    t_tok = strtok(NULL,",");
 
-		  } 
+		  }
 
 		if (found==1)
-		  strcat(newstr,"1"); 
+		  strcat(newstr,"1");
 		else
 		  strcat(newstr,"0");
 	      }
@@ -604,7 +611,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	else
 	  {
 	    strcpy(output,psr->param[ip].ref);
-	    upperCase(output);	    
+	    upperCase(output);
 	    if (strstr(output,storeStr)!=NULL)
 	      strcat(newstr,"1");
 	    else
@@ -656,10 +663,10 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 			break;
 		      }
 		    t_tok = strtok(NULL,",");
-		  } 
+		  }
 
 		if (found==1)
-		  strcat(newstr,"1"); 
+		  strcat(newstr,"1");
 		else
 		  strcat(newstr,"0");
 	      }
@@ -705,7 +712,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	char *tempptr2;
 	strcpy(tempStr,tempptr+1);
 	strcpy(storeStr, tempStr);
-	
+
 	tempptr2 = strpbrk(storeStr,")");
 	tempptr2[0] = '\0';
 	if ((ip = getParam("SURVEY",psr))==-1)
@@ -727,12 +734,12 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	    if (exactMatch==0)
 	      {
 	    //
-	    //	    if (strcasestr(first,storeStr)!=0)
+	    //	    if (strcasecmp(first,storeStr)!=0)
 	    //	      strcat(newstr,"1");
 	    //	    else
 	    //	      strcat(newstr,"0");
 
-		if (strcasestr(first,storeStr)!=0)
+		if (strcasecmp(first,storeStr)!=0)
 		  strcat(newstr,"1");
 		else
 		  strcat(newstr,"0");
@@ -744,14 +751,14 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 		int found=0;
 
 		if (strcasecmp(first,storeStr)==0)
-		  strcat(newstr,"1"); 
+		  strcat(newstr,"1");
 		else
 		  strcat(newstr,"0");
 	      }
 	  }
-	strcpy(tempStr,tempptr2+1);	
+	strcpy(tempStr,tempptr2+1);
 	strcpy(storeStr,tempStr);
-	storeCharstr[0]='\0';	
+	storeCharstr[0]='\0';
       }
     else if (strcmp(storeStr,"TYPE")==0)
       {
@@ -765,7 +772,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	ipb = getParam("BINARY",NULL);
 	ip2 = getParam("PB",NULL);
 	ip = getParam("TYPE",NULL);
-	
+
 	if ((ip = getParam("TYPE",NULL))==-1)
 	  strcat(newstr,"0");
 	else if (psr->param[ip].set1==1 && strstr(psr->param[ip].val,storeStr)!=NULL)
@@ -779,7 +786,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	  strcat(newstr,"0");
 	strcpy(tempStr,tempptr2+1);
 	strcpy(storeStr,tempStr);
-	storeCharstr[0]='\0';	
+	storeCharstr[0]='\0';
       }
     else if (strcmp(storeStr,"DMS")==0 || strcmp(storeStr,"D")==0)
       {
@@ -827,7 +834,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	    char output[100];
 
 	    sscanf(psr->param[ip].err,"%d",&ierr);
-	    sprintf(output,"%.6g\0",psr->param[ip].error_expand*ierr); /* Check errors to 6 decimal places */ 
+	    sprintf(output,"%.6g\\0",psr->param[ip].error_expand*ierr); /* Check errors to 6 decimal places */
 	    strcat(newstr,output);
 	  }
 	else
@@ -848,9 +855,9 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
 	if (psr->param[ip].set1!=1) /* This was commented out -- why??? */
 	  {
 	    *badval=1;
-	    return 0; 
+	    return 0;
 	  }
-	strcat(newstr,psr->param[ip].val);	    
+	strcat(newstr,psr->param[ip].val);
 	if (tempptr!=NULL)
 	  {
 	    strcpy(tempStr,tempptr+1);
@@ -867,13 +874,13 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
       }
     if (tempptr!=NULL) strcat(newstr,storeCharstr);
   } while (tempptr!=NULL);
-  //    printf("Final string = :%s:\n",newstr);  
+  //    printf("Final string = :%s:\n",newstr);
 
   /* Convert to lowercase */
   for (i=strlen(newstr);i--;)
     newstr[i]=tolower(newstr[i]);
   errorFlag = evaluateExpression(newstr);
-  //      printf("%s Evaluating ~%s~ output = %f %d\n",psr->param[0].val,newstr,variable[0].value,errorFlag);   
+  //      printf("%s Evaluating ~%s~ output = %f %d\n",psr->param[0].val,newstr,variable[0].value,errorFlag);
 
   if (errorFlag)
     {
@@ -881,7 +888,7 @@ double formExpression(char *filterStr,pulsar *psr,int *badval,int exactMatch)
       return 0;
     }
   return variable[0].value;
-  
+
 }
 
 /* Parameters that are always derived: P0, P1, F0 and F1 */
@@ -900,7 +907,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
   /* Copy reference from BNAME to JNAME */
   if (psr->param[1].set3==1)
     {strcpy(psr->param[0].ref,psr->param[1].ref); psr->param[0].set3=1;}
- 
+
   f0 = getParam("F0",NULL);
   f1 = getParam("F1",NULL);
   p0 = getParam("P0",NULL);
@@ -920,8 +927,8 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	{
 	  sscanf(psr->param[f0].err,"%d",&ierr_f0);
 	  psr->param[p0].error_expand = psr->param[f0].error_expand*ierr_f0*p0val*p0val;
-	  
 	  rnd8(p0val,psr->param[p0].error_expand,1,psr->param[p0].val,&lv,psr->param[p0].err,&le,msg);
+		 
 	  psr->param[p0].error_expand = errscale(psr->param[p0].val,psr->param[p0].err);
 	  psr->param[p0].set2 = 1;
 	  psr->param[p0].derived = 1;
@@ -941,7 +948,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	}
       else
 	psr->param[p0].set3 = 0;
-      psr->param[p0].set1 = 1;  
+      psr->param[p0].set1 = 1;
 
     }
   else if (psr->param[p0].set1 == 1 && psr->param[f0].set1 != 1) /* Derive frequency from period */
@@ -970,7 +977,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	    }
 	  else
 	    psr->param[f0].set3 = 0;
-	  psr->param[f0].set1 = 1; psr->param[f0].set2 = 0; 
+	  psr->param[f0].set1 = 1; psr->param[f0].set2 = 0;
 	  psr->param[f0].derived = 1;
 	}
       /* Derive F1 from P1 if available */
@@ -997,7 +1004,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	      psr->param[f1].set1 = 1; psr->param[f1].set2 = 0; psr->param[f1].set3 = 1;
 	      psr->param[f1].derived = 1;
 	    }
-	}      
+	}
       /* Derive P1 from F1 if available */
       if (psr->param[f1].set1 == 1 && psr->param[p1].set1 == 0)
 	{
@@ -1051,7 +1058,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	  sprintf(psr->param[p1].val,defparam[p1].shortStr,p1val);
 	  psr->param[p1].derived = 1;
 	}
-      psr->param[p1].set1 = 1;  
+      psr->param[p1].set1 = 1;
       if (psr->param[f0].set3==1)
 	{
 	  strcpy(psr->param[p1].ref,psr->param[f0].ref);
@@ -1067,18 +1074,18 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
   /* Derive PB from FB0 */
   if (psr->param[fb0].set1 == 1 && psr->param[pb].set1 != 1)
     {
-      
+
       pbval = (1.0/psr->param[fb0].shortVal)/86400.0;
       psr->param[pb].shortVal = pbval;
       pcat_errZero[pb]=-1;
       pcat_refZero[pb]=-1;
-	  
+
       if (psr->param[fb0].set2==1)
 	{
 	  sscanf(psr->param[fb0].err,"%d",&ierr_fb0);
 	  //	  psr->param[pb].error_expand = psr->param[fb0].error_expand/86400.0*ierr_fb0*pbval*pbval;
 	  psr->param[pb].error_expand = psr->param[fb0].error_expand*ierr_fb0*pbval*86400.0*pbval;
-	  
+
 	  rnd8(pbval,psr->param[pb].error_expand,1,psr->param[pb].val,&lv,psr->param[pb].err,&le,msg);
 	  psr->param[pb].error_expand = errscale(psr->param[pb].val,psr->param[pb].err);
 	  psr->param[pb].set2 = 1;
@@ -1099,7 +1106,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	}
       else
 	psr->param[pb].set3 = 0;
-      psr->param[pb].set1 = 1;  
+      psr->param[pb].set1 = 1;
       psr->param[pb].derived = 1;
 
       /* Derive PBDOT from FB1 if available */
@@ -1150,8 +1157,8 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	  psr->param[fb0].error_expand = errscale(psr->param[fb0].val,psr->param[fb0].err);
 	  strcpy(psr->param[fb0].ref,psr->param[pb].ref);
 	  psr->param[fb0].set1 = 1; psr->param[fb0].set2 = 1; psr->param[fb0].set3 = 1;
-	  if (pcat_maxSize[fb0] < strlen(psr->param[fb0].val)) 
-	    pcat_maxSize[fb0]=strlen(psr->param[fb0].val);	      
+	  if (pcat_maxSize[fb0] < strlen(psr->param[fb0].val))
+	    pcat_maxSize[fb0]=strlen(psr->param[fb0].val);
 	  psr->param[fb0].derived = 1;
 	}
       else /* No error */
@@ -1165,7 +1172,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	    }
 	  else
 	    psr->param[fb0].set3 = 0;
-	  psr->param[fb0].set1 = 1; psr->param[fb0].set2 = 0; 
+	  psr->param[fb0].set1 = 1; psr->param[fb0].set2 = 0;
 	  psr->param[fb0].derived = 1;
 	}
       /* Derive FB1 from PBDOT if available */
@@ -1227,7 +1234,7 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	  psr->param[pbdot].set2 = 0;
 	  sprintf(psr->param[pbdot].val,defparam[pbdot].shortStr,pbdotval);
 	}
-      psr->param[pbdot].set1 = 1;  
+      psr->param[pbdot].set1 = 1;
       psr->param[pbdot].derived = 1;
 
       if (psr->param[fb0].set3==1)
@@ -1263,10 +1270,10 @@ void alwaysDerive(pulsar *psr,paramtype *defparam)
 	  psr->param[eph].set1 = 1;
       }
 
-	
+
     }
   */
-    if (psr->param[units].set1 == 0) // Use UNITS TDB as default, but check for EPHVER 5 
+    if (psr->param[units].set1 == 0) // Use UNITS TDB as default, but check for EPHVER 5
       {
 	if (psr->param[eph].set1 == 1)
 	  {
@@ -1303,6 +1310,7 @@ int rnd8(double rval,double rerr,int ifac,char *cval,int *lv,char *cerr,int *le,
   int ixv, ixe, iee, j, ivv, ise, irnd, ilim,ret,ret_lv,ret_le;
   char cexp[9], fmt[12];
   char temp[1024];
+  double epsilon = 1.0e-40;
 
   ilim = 4;
 
@@ -1324,9 +1332,14 @@ int rnd8(double rval,double rerr,int ifac,char *cval,int *lv,char *cerr,int *le,
   ixv=fabs(xv);
   if (xv<0.0)ixv=-ixv-1;
 
-  xe = log10(ee/2.0)+1.0e-10;
+  /* avoid -inf, which leads to integer underflow */
+  if (ee > epsilon) {
+      xe = log10( ee/2.0 ) + epsilon;
+  } else {
+    xe = epsilon;
+  }
   ixe = fabs(xe);
-  if (xe<0.0)ixe=-ixe-1; 
+  if (xe<0.0)ixe=-ixe-1;
   ise=ixe-ixv; /* Scale of error wrt value */
 
   ixv = -ixv; /* Reverse signs of scale factors */
@@ -1360,10 +1373,10 @@ int rnd8(double rval,double rerr,int ifac,char *cval,int *lv,char *cerr,int *le,
 	  if (ise<1) /* If err > 0.2, print val as fn.1 and scale error */
 	    {
 	      ee=ee*pow(10.0,1-ise);
-	      ise=1; 
+	      ise=1;
 	    }
 	  strcpy(cexp," ");
-	  sprintf(cexp,"%d",-ixv); 
+	  sprintf(cexp,"%d",-ixv);
 	  j=0; /* Strip off leading blanks */
 	  do
 	    {
@@ -1379,7 +1392,7 @@ int rnd8(double rval,double rerr,int ifac,char *cval,int *lv,char *cerr,int *le,
 	  else
 	    sprintf(fmt,"%%%d.%df",ise+3,ise);
 	  sprintf(cval,fmt,vv);
-	  if (cval[0]==' ') 
+	  if (cval[0]==' ')
 	    {
 	      strcpy(temp,cval+1);
 	      strcpy(cval,temp);
@@ -1410,12 +1423,12 @@ int rnd8(double rval,double rerr,int ifac,char *cval,int *lv,char *cerr,int *le,
 	}
     }
 
-  if (cval[0]==' ') 
+  if (cval[0]==' ')
     {
       strcpy(temp,cval+1);
       strcpy(cval,temp);  /* For positive numbers */
     }
-  ret_lv=strlen(cval)-1; 
+  ret_lv=strlen(cval)-1;
 
   irnd = log10(ee/2.0);
   if (irnd>1) /* Round error */
@@ -1461,7 +1474,7 @@ int checkBoundary(char *boundary,pulsar *psr)
   int type;
   int ip1,ip2,ip3,nread;
 
-  ip1 = getParam("RAJD",psr); 
+  ip1 = getParam("RAJD",psr);
   ip2 = getParam("DECJD",psr);
 
   psr_long = psr->param[ip1].shortVal;
@@ -1477,12 +1490,12 @@ int checkBoundary(char *boundary,pulsar *psr)
   else if (type==2)  /* Format raj_deg decj_deg */
     {
       sscanf(centre_long_str,"%lf",&centre_long);
-      sscanf(centre_lat_str,"%lf",&centre_lat);    
+      sscanf(centre_lat_str,"%lf",&centre_lat);
     }
   else if (type==3)  /* Format gl gb */
     {
       sscanf(centre_long_str,"%lf",&centre_long);
-      sscanf(centre_lat_str,"%lf",&centre_lat);    
+      sscanf(centre_lat_str,"%lf",&centre_lat);
       ip1 = getParam("GL",psr);
       ip2 = getParam("GB",psr);
       psr_long = psr->param[ip1].shortVal;
@@ -1491,12 +1504,12 @@ int checkBoundary(char *boundary,pulsar *psr)
   /* Apply the Haversine formula */
   dlon = (psr_long - centre_long)*deg2rad;
   dlat = (psr_lat  - centre_lat)*deg2rad;
-  a = pow(sin(dlat/2.0),2) + cos(centre_lat*deg2rad) * 
+  a = pow(sin(dlat/2.0),2) + cos(centre_lat*deg2rad) *
     cos(psr_lat*deg2rad)*pow(sin(dlon/2.0),2);
   if (a==1)
     c = M_PI;
   else
-    c = 2.0 * atan2(sqrt(a),sqrt(1.0-a))/deg2rad;  
+    c = 2.0 * atan2(sqrt(a),sqrt(1.0-a))/deg2rad;
   /* Now place the distance in raddist */
   ip3 = getParam("RADDIST",NULL);
   sprintf(psr->param[ip3].val,"%-8.3g",c);
@@ -1600,7 +1613,7 @@ void checkCatalogue(FILE *fin,char *fname)
 	{
 	  check_parameter(fline,&haveP,&haveF,&haveJ2000,&haveEclip,&haveDM,&haveDistDM,&haveDistDM1,&haveBIN,&havePB,&haveOM,&haveECC,&haveEPS1,&haveEPS2,current_psr,&bintype,&errornum);
 	  /*	  check_reference(fline,&errornum,current_psr);*/
-	  check_values(fline,&errornum,current_psr); 
+	  check_values(fline,&errornum,current_psr);
 	}
     }
 }
@@ -1613,10 +1626,10 @@ void check_parameter(char* fline,int *haveP,int *haveF,int *haveJ2000,int *haveE
   int ok=0;
 
   sscanf(fline,"%s",label);
-  if (strcmp(label,"PSRJ")==0) 
+  if (strcmp(label,"PSRJ")==0)
     {
-      ok=1; 
-      if (strcmp(current_psr,"unknown")==0) sscanf(fline,"%s %s",label,current_psr);      
+      ok=1;
+      if (strcmp(current_psr,"unknown")==0) sscanf(fline,"%s %s",label,current_psr);
       else
 	{
 	  sscanf(fline,"%s %s",label,name);
@@ -1688,7 +1701,7 @@ void check_parameter(char* fline,int *haveP,int *haveF,int *haveJ2000,int *haveE
   else if (strcmp(label,"A1")==0) {ok=1; check_error(fline,current_psr,errornum);}
   else if (strcmp(label,"PB")==0) {ok=1; check_error(fline,current_psr,errornum); *havePB=1;}
   else if (strcmp(label,"BINARY")==0) {
-    ok=1; 
+    ok=1;
     *haveBIN=1;
     sscanf(fline,"%s %s",label,name);
     if (strcmp(name,"ELL1")==0)
@@ -1713,15 +1726,15 @@ void check_parameter(char* fline,int *haveP,int *haveF,int *haveJ2000,int *haveE
   else if (strcmp(label,"INTERIM")==0) ok=1;
   else if (strcmp(label,"OM_2")==0) {ok=1; check_error(fline,current_psr,errornum);}
   else if (strcmp(label,"OM_3")==0) {ok=1; check_error(fline,current_psr,errornum);}
-  else if (strcmp(label,"TRES")==0) ok=1;  
-  else if (strcmp(label,"NSPAN")==0) ok=1;  
-  else if (strcmp(label,"NTCOEF")==0) ok=1;  
-  else if (strcmp(label,"NFCOEF")==0) ok=1;  
-  else if (strcmp(label,"PREDLEN")==0) ok=1;  
-  else if (strcmp(label,"NCOEF")==0) ok=1;  
-  else if (strcmp(label,"FBTSUB")==0) ok=1;  
-  else if (strcmp(label,"FBNBIN")==0) ok=1;  
-  else if (strcmp(label,"FBNCHN")==0) ok=1;  
+  else if (strcmp(label,"TRES")==0) ok=1;
+  else if (strcmp(label,"NSPAN")==0) ok=1;
+  else if (strcmp(label,"NTCOEF")==0) ok=1;
+  else if (strcmp(label,"NFCOEF")==0) ok=1;
+  else if (strcmp(label,"PREDLEN")==0) ok=1;
+  else if (strcmp(label,"NCOEF")==0) ok=1;
+  else if (strcmp(label,"FBTSUB")==0) ok=1;
+  else if (strcmp(label,"FBNBIN")==0) ok=1;
+  else if (strcmp(label,"FBNCHN")==0) ok=1;
   else if (strcmp(label,"ECC_2")==0) {ok=1; check_error(fline,current_psr,errornum);}
   else if (strcmp(label,"ECC_3")==0) {ok=1; check_error(fline,current_psr,errornum);}
   else if (strcmp(label,"A1_2")==0) {ok=1; check_error(fline,current_psr,errornum);}
@@ -1769,7 +1782,7 @@ void check_error(char *fline,char *current_psr,int *errornum)
 	    {
 	      if (error[i]=='.')
 		printf("%4d. [ERROR04] Non-integral uncertainty on %s for pulsar %s\n",
-		       (*errornum)++,label,current_psr);	      
+		       (*errornum)++,label,current_psr);
 	    }
 	  if (derror==0.0)
 	    printf("%4d. [ERROR10] Zero uncertainty on %s for pulsar %s\n",
@@ -1781,7 +1794,7 @@ void check_error(char *fline,char *current_psr,int *errornum)
 	}
       else
 	{
-	  if (strcmp(label,"S1400")!=0 && strcmp(label,"S400")!=0 && 
+	  if (strcmp(label,"S1400")!=0 && strcmp(label,"S400")!=0 &&
 	      strcmp(label,"S600")!=0 && strcmp(label,"S900")!=0 &&
 	      strcmp(label,"S700")!=0 && strcmp(label,"S3000")!=0
 	      && strcmp(label,"S30")!=0
@@ -1798,7 +1811,7 @@ void check_error(char *fline,char *current_psr,int *errornum)
 	      & strcmp(label,"S100")!=0 && strcmp(label,"S1600")!=0  && strcmp(label,"W10")!=0
 	      && strcmp(label,"W50")!=0)
 	    printf("%4d. [ERROR03] Something wrong with uncertainty on %s for pulsar %s\n",
-		   (*errornum)++,label,current_psr);	  
+		   (*errornum)++,label,current_psr);
 	}
     }
 }
@@ -1826,7 +1839,7 @@ void check_reference(char* fline,int *errornum,char *current_psr)
     }
   if (ok==0)
     {
-      if (strcmp(label,"START")!=0 && strcmp(label,"CATALOGUE")!=0 && 
+      if (strcmp(label,"START")!=0 && strcmp(label,"CATALOGUE")!=0 &&
 	  strcmp(label,"FINISH")!=0 && strcmp(label,"CLK")!=0
 	  && strcmp(label,"EPHEM")!=0 && strcmp(label,"BINARY")!=0 && strcmp(label,"TZRMJD")!=0
 	  && strcmp(label,"TZRFRQ")!=0 && strcmp(label,"TZRSITE")!=0 && strcmp(label,"SURVEY")!=0
@@ -1834,7 +1847,7 @@ void check_reference(char* fline,int *errornum,char *current_psr)
           && strcmp(label,"BINCOMP")!=0
 	  && strcmp(label,"POSEPOCH")!=0 && strcmp(label,"DMEPOCH")!=0 && strcmp(label,"NTOA")!=0 && strcmp(label,"TRES")!=0
 	  && strcmp(label,"PSRJ")!=0 && strcmp(label,"TYPE")!=0 && strcmp(label,"DIST_A")!=0
-	  && strcmp(label,"NGLT")!=0 && strcmp(label,"INTERIM")!=0  && strcmp(label,"NSPAN")!=0 
+	  && strcmp(label,"NGLT")!=0 && strcmp(label,"INTERIM")!=0  && strcmp(label,"NSPAN")!=0
 	  && strcmp(label,"NCOEF")!=0 && strcmp(label,"NOTE")!=0  && strcmp(label,"NITS")!=0)
 	printf("%4d. [ERROR05] No reference on %s for pulsar %s\n",(*errornum)++,label,current_psr);
     }
@@ -1850,8 +1863,8 @@ void check_values(char *fline,int *errornum,char *current_psr)
       nread = sscanf(fline,"%s %lf",label,&value);
 
   if (strcmp(label,"CLK")!=0 && strcmp(label,"SURVEY")!=0 && strcmp(label,"TYPE")!=0
-      && strcmp(label,"PSRJ")!=0 && strcmp(label,"PSRB")!=0 && strcmp(label,"EPHEM")!=0 
-      && strcmp(label,"CATALOGUE")!=0 && strcmp(label,"BINARY")!=0 
+      && strcmp(label,"PSRJ")!=0 && strcmp(label,"PSRB")!=0 && strcmp(label,"EPHEM")!=0
+      && strcmp(label,"CATALOGUE")!=0 && strcmp(label,"BINARY")!=0
       && strcmp(label,"ALIAS")!=0 && strcmp(label,"ASSOC")!=0 && strcmp(label,"BINCOMP")!=0 && strcmp(label,"INTERIM")!=0
       && strcmp(label,"NOTE")!=0 && strcmp(label,"TZRSITE")!=0)
     {
